@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -78,3 +78,9 @@ Action::match_key_event (const KeyEvent &key)
 {
     return util_match_key_event (m_key_bindings, key, SCIM_KEY_CapsLockMask);
 }
+
+bool
+Action::match_action_name (const char *name)
+{
+    return (m_name.compare (name) == 0);
+}
