@@ -14,16 +14,21 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <string.h>
+
 #include "scim_anthy_factory.h"
 #include "scim_anthy_imengine.h"
 #include "scim_anthy_conversion.h"
 #include "scim_anthy_utils.h"
+#include "scim_anthy_prefs.h"
 
 using namespace scim_anthy;
 
+static unsigned int anthy_ref_count = 0;
+
 static void rotate_case (String &str);
 
 
@@ -87,7 +92,14 @@ Conversion::Conversion (AnthyInstance &anthy, Reading &reading)
       m_cur_segment        (-1),
       m_predicting         (false)
 {
-    set_dict_encoding (String ("EUC-JP"));
+    if (!anthy_ref_count) {
+        if (anthy_init()) {
+            SCIM_DEBUG_IMENGINE(1) << "Failed to initialize Anthy Library!\n";
+        }
+    }
+    anthy_ref_count++;
+
+    set_dict_encoding (String (SCIM_ANTHY_CONFIG_DICT_ENCODING_DEFAULT));
 
 #ifdef HAS_ANTHY_SET_RECONVERSION_MODE
     anthy_set_reconversion_mode (m_anthy_context, ANTHY_RECONVERT_DISABLE);
@@ -97,6 +109,11 @@ Conversion::Conversion (AnthyInstance &anthy, Reading &reading)
 Conversion::~Conversion ()
 {
     anthy_release_context (m_anthy_context);
+
+    if (anthy_ref_count)
+        anthy_ref_count--;
+    if (!anthy_ref_count)
+        anthy_quit();
 }
 
 
