@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -65,21 +65,13 @@ extern "C" {
 
     void scim_module_exit (void)
     {
-        anthy_quit ();
         _scim_config.reset ();
     }
 
     uint32 scim_imengine_module_init (const ConfigPointer &config)
     {
         SCIM_DEBUG_IMENGINE(1) << "Initialize Anthy Engine.\n";
-
         _scim_config = config;
-
-        if (anthy_init ()) {
-            SCIM_DEBUG_IMENGINE(1) << "Failed to initialize Anthy Library!\n";
-            return 0;
-        }
-
         return 1;
     }
 
@@ -147,7 +139,8 @@ AnthyFactory::AnthyFactory (const String &lang,
       m_selected_segment_style      (SCIM_ANTHY_CONFIG_SELECTED_SEGMENT_STYLE_DEFAULT),
       m_custom_romaji_table         (NULL),
       m_custom_kana_table           (NULL),
-      m_custom_nicola_table         (NULL)
+      m_custom_nicola_table         (NULL),
+      m_kana_layout_ro_key          (SCIM_ANTHY_CONFIG_KANA_LAYOUT_RO_KEY)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create Anthy Factory :\n";
     SCIM_DEBUG_IMENGINE(1) << "  Lang : " << lang << "\n";
@@ -213,6 +206,10 @@ AnthyFactory::get_credits () const
     return utf8_mbstowcs (
         _("Art work:\n"
           "  SHIMODA Hiroshi <piro@p.club.ne.jp>\n"
+          "\n"
+          "Translate:\n"
+          "  Gerrit Sangel <z0idberg@gmx.de>"
+          "\n"
           "Special thanks:\n"
           "  UTUMI Hirosi <utuhiro78@yahoo.co.jp>\n"
           "  Yukiko Bando <ybando@k6.dion.ne.jp>\n"
@@ -245,8 +242,8 @@ AnthyFactory::get_help () const
     const char *text2 = 
         _("2. Input Japanese hiragana and katakana:\n"
           "  You can input Japanese hiragana and katakana by inputting romaji.\n"
-          "  Romaji table will be find out from \"Anthy\" section on a setup window of\n"
-          "  SCIM or SKIM.\n"
+          "  The Romaji table can be found out from the \"Anthy\" section of the setup\n"
+          "  window in SCIM or SKIM.\n"
           "  If you want to hiragana and katakana directly by using Japanese keyboard,\n"
           "  please press Alt + Romaji key or Conrol+\\ key to switch typing method.\n"
           "  \n");
@@ -255,10 +252,10 @@ AnthyFactory::get_help () const
         _("3. Convert hiragana or katakana to Japanese kanji\n"
           "  After inputting hiragana or katakana, you can convert it to Japanese\n"
           "  kanji by pressing Space key. Then it will show some candidates. You can\n"
-          "  select a next candidate by pressing Space key, and can commit it by\n"
+          "  select the next candidate by pressing Space key, and can commit it by\n"
           "  pressing Enter key.\n"
           "  If you input a sentense, Anthy will split it to some segments. You can\n"
-          "  select a next or previous segment by pressing left or right cursor key,\n"
+          "  select the next or previous segment by pressing left or right cursor key,\n"
           "  and can extend or shrink the selected segment by pressing Shift + left or\n"
           "  right cursor key.\n"
           "  \n");
@@ -776,6 +773,11 @@ AnthyFactory::reload_config (const ConfigPointer &config)
         m_custom_nicola_table = style.get_key2kana_table (section_nicola);
     }
 
+    // special kana keys
+    m_kana_layout_ro_key
+        = config->read (String (SCIM_ANTHY_CONFIG_KANA_LAYOUT_RO_KEY),
+                        String (SCIM_ANTHY_CONFIG_KANA_LAYOUT_RO_KEY_DEFAULT));
+
 
     // reload config for all instance
     std::vector<AnthyInstance*>::iterator it;
