@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -29,7 +29,6 @@
 
 #define Uses_SCIM_IMENGINE
 #define Uses_SCIM_CONFIG_BASE
-#include <anthy/anthy.h>
 #include <scim.h>
 #include "scim_anthy_action.h"
 #include "scim_anthy_style_file.h"
@@ -136,6 +135,8 @@ public:
     Key2KanaTable *m_custom_kana_table;
     Key2KanaTable *m_custom_nicola_table;
 
+    String         m_kana_layout_ro_key;
+
     /* for key bindings */
     std::vector<Action> m_actions;
 };
