@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define Uses_SCIM_HELPER
@@ -28,10 +28,13 @@
 #include <gtk/gtk.h>
 #include "scim_anthy_intl.h"
 #include "scim_anthy_helper.h"
-#include "scim_anthy_tray.h"
 #include "scim_anthy_const.h"
 #include "scim_anthy_prefs.h"
 
+#ifdef SCIM_ANTHY_BUILD_TRAY
+#include "scim_anthy_tray.h"
+#endif
+
 using namespace scim;
 
 #define scim_module_init anthy_imengine_helper_LTX_scim_module_init
@@ -61,9 +64,11 @@ static void       timeout_ctx_destroy_func    (gpointer             data);
 static void       run                         (const String        &display,
                                                const ConfigPointer &config);
 
-AnthyHelper *helper = NULL;
-AnthyTray   *tray   = NULL;
 HelperAgent  helper_agent;
+AnthyHelper *helper = NULL;
+#ifdef SCIM_ANTHY_BUILD_TRAY
+AnthyTray   *tray   = NULL;
+#endif
 
 HelperInfo helper_info (SCIM_ANTHY_HELPER_UUID,        // uuid
                         "",                            // name
@@ -152,10 +157,12 @@ helper_agent_input_handler (GIOChannel *source,
 static void
 slot_exit (const HelperAgent *agent, int ic, const String &uuid)
 {
+#ifdef SCIM_ANTHY_BUILD_TRAY
     if (tray != NULL) {
         delete tray;
         tray = NULL;
     }
+#endif
 
     if (helper != NULL) {
         delete helper;
@@ -211,9 +218,9 @@ slot_imengine_event (const HelperAgent *agent, int ic,
         if (!reader.get_data (id) || !reader.get_data (time_msec))
             break;
         TimeoutContext *ctx = new TimeoutContext (ic, uuid, id);
-        guint timeout_id = gtk_timeout_add_full (time_msec,
+        guint timeout_id = g_timeout_add_full (G_PRIORITY_DEFAULT,
+						 time_msec,
                                                  timeout_func,
-                                                 NULL,
                                                  (gpointer) ctx,
                                                  timeout_ctx_destroy_func);
         timeout_ids[ic][id] = timeout_id;
@@ -227,7 +234,7 @@ slot_imengine_event (const HelperAgent *agent, int ic,
             timeout_ids[ic].find (id) != timeout_ids[ic].end ())
         {
             guint tid = timeout_ids[ic][id];
-            gtk_timeout_remove (tid);
+            g_source_remove (tid);
         }
         break;
     }
@@ -284,6 +291,7 @@ slot_imengine_event (const HelperAgent *agent, int ic,
         helper->update_note (str);
         break;
     }
+#ifdef SCIM_ANTHY_BUILD_TRAY
     case SCIM_ANTHY_TRANS_CMD_SET_INPUT_MODE:
     {
         uint32 mode;
@@ -322,6 +330,7 @@ slot_imengine_event (const HelperAgent *agent, int ic,
 
         break;
     }
+#endif // SCIM_ANTHY_BUILD_TRAY
     default:
         break;
     }
@@ -345,20 +354,22 @@ slot_attach_input_context   (const HelperAgent   *agent,
                              int                  ic,
                              const String        &ic_uuid)
 {
+#ifdef SCIM_ANTHY_BUILD_TRAY
     if (tray != NULL)
     {
         tray->attach_input_context (agent, ic, ic_uuid);
+    }
+#endif
 
-        InputContext input_context;
-        input_context.agent = agent;
-        input_context.ic = ic;
-        input_context.ic_uuid = ic_uuid;
-        helper->attach_input_context (input_context);
+    InputContext input_context;
+    input_context.agent = agent;
+    input_context.ic = ic;
+    input_context.ic_uuid = ic_uuid;
+    helper->attach_input_context (input_context);
 
-        Transaction send;
-        send.put_command (SCIM_ANTHY_TRANS_CMD_ATTACHMENT_SUCCESS);
-        helper_agent.send_imengine_event (ic, ic_uuid, send);
-    }    
+    Transaction send;
+    send.put_command (SCIM_ANTHY_TRANS_CMD_ATTACHMENT_SUCCESS);
+    helper_agent.send_imengine_event (ic, ic_uuid, send);
 }
 
 static gint
@@ -405,7 +416,9 @@ run (const String &display, const ConfigPointer &config)
     gtk_init (&argc, &argv);
 
     helper = new AnthyHelper;
+#ifdef SCIM_ANTHY_BUILD_TRAY
     tray = new AnthyTray;
+#endif
 
     helper->init (config, argv[2]);
 
@@ -609,11 +622,17 @@ AnthyHelper::init (const ConfigPointer &config, const char *dsp)
     if (m_helper_window == NULL)
         return;
     gtk_window_set_default_size (GTK_WINDOW (m_helper_window), 100, 20);
+/*
     gtk_window_set_policy (GTK_WINDOW (m_helper_window),
                            TRUE, TRUE, FALSE);
+*/
     gtk_window_set_resizable (GTK_WINDOW (m_helper_window), FALSE);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    m_helper_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
     m_helper_vbox = gtk_vbox_new (FALSE, 0);
+#endif
     if (m_helper_vbox == NULL)
         return;
     gtk_container_add (GTK_CONTAINER (m_helper_window),
@@ -639,7 +658,11 @@ AnthyHelper::init (const ConfigPointer &config, const char *dsp)
 
     // lookup table
     m_lookup_table_visible = false;
+#if GTK_CHECK_VERSION(3, 0, 0)
+    m_lookup_table_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
     m_lookup_table_vbox = gtk_vbox_new (TRUE, 0);
+#endif
     if (m_lookup_table_vbox == NULL)
         return;
     gtk_box_pack_end (GTK_BOX(m_helper_vbox),
@@ -653,8 +676,10 @@ AnthyHelper::init (const ConfigPointer &config, const char *dsp)
     if (m_note_window == NULL)
         return;
     gtk_window_set_default_size (GTK_WINDOW (m_note_window), 100, 20);
+/*
     gtk_window_set_policy (GTK_WINDOW (m_note_window),
                            TRUE, TRUE, FALSE);
+*/
     gtk_window_set_resizable (GTK_WINDOW (m_note_window), FALSE);
 
     m_note_event_box = gtk_event_box_new ();
@@ -820,8 +845,8 @@ AnthyHelper::hide_aux_string (void)
     else
     {
         // hide the helper window
-        gtk_widget_show (m_helper_vbox);
-        gtk_widget_show (m_helper_window);
+        gtk_widget_hide (m_helper_vbox);
+        gtk_widget_hide (m_helper_window);
     }
 }
 
@@ -854,8 +879,8 @@ AnthyHelper::hide_lookup_table (void)
     else
     {
         // hide the helper window
-        gtk_widget_show (m_helper_vbox);
-        gtk_widget_show (m_helper_window);
+        gtk_widget_hide (m_helper_vbox);
+        gtk_widget_hide (m_helper_window);
     }
 }
 
@@ -1014,7 +1039,11 @@ AnthyHelper::hide_note ()
 
     m_note_visible = false;
 
+#if GTK_CHECK_VERSION(2, 24, 0)
+    gtk_widget_hide (m_note_window);
+#else
     gtk_widget_hide_all (m_note_window);
+#endif
 }
 
 void
