@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -347,13 +347,8 @@ AnthyInstance::select_candidate_no_direct (unsigned int item)
     set_preedition ();
 
     // update aux string
-    if (m_factory->m_show_candidates_label) {
-        char buf[256];
-        sprintf (buf, _("Candidates (%d/%d)"),
-                 m_lookup_table.get_cursor_pos () + 1,
-                 m_lookup_table.number_of_candidates ());
-        update_aux_string_advanced (utf8_mbstowcs (buf));
-    }
+    if (m_factory->m_show_candidates_label)
+        set_aux_string ();
 }
 
 void
@@ -419,6 +414,10 @@ AnthyInstance::reset ()
     m_lookup_table.clear ();
     unset_lookup_table ();
 
+    hide_lookup_table_advanced ();
+    hide_aux_string_advanced ();
+    hide_note ();
+
     hide_preedit_string ();
     m_preedit_string_visible = false;
     set_preedition ();
@@ -440,6 +439,14 @@ AnthyInstance::focus_in ()
     }
 
     if (m_lookup_table_visible && is_selecting_candidates ()) {
+        if (m_factory->m_show_candidates_label &&
+            m_lookup_table.number_of_candidates() > 0)
+        {
+            set_aux_string ();
+            show_aux_string_advanced ();
+        } else {
+            hide_aux_string ();
+        }
         update_lookup_table_advanced (m_lookup_table);
         show_lookup_table_advanced ();
     } else {
@@ -483,6 +490,16 @@ AnthyInstance::set_preedition (void)
     update_preedit_caret (m_preedit.get_caret_pos());
 }
 
+void
+AnthyInstance::set_aux_string (void)
+{
+    char buf[256];
+    sprintf (buf, _("Candidates (%d/%d)"),
+             m_lookup_table.get_cursor_pos () + 1,
+             m_lookup_table.number_of_candidates ());
+    update_aux_string_advanced (utf8_mbstowcs (buf));
+}
+
 void
 AnthyInstance::set_lookup_table (void)
 {
@@ -526,11 +543,7 @@ AnthyInstance::set_lookup_table (void)
         m_n_conv_key_pressed = 0;
 
         if (m_factory->m_show_candidates_label) {
-            char buf[256];
-            sprintf (buf, _("Candidates (%d/%d)"),
-                     m_lookup_table.get_cursor_pos () + 1,
-                     m_lookup_table.number_of_candidates ());
-            update_aux_string_advanced (utf8_mbstowcs (buf));
+            set_aux_string ();
             show_aux_string_advanced ();
 
             // find diction
@@ -760,7 +773,7 @@ AnthyInstance::install_properties (void)
                 prop = Property (SCIM_PROP_DICT_ADD_WORD,
                                  _("Add a word"),
                                  String (SCIM_ICONDIR "/" "scim-anthy-dict.png"),
-                                 _("Add a word to the dictorinay."));
+                                 _("Add a word to the dictionary."));
                 m_properties.push_back (prop);
             }
         }
