@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -30,7 +30,6 @@
 #define Uses_SCIM_IMENGINE
 #define Uses_SCIM_CONFIG_BASE
 #include <map>
-#include <anthy/anthy.h>
 #include <scim.h>
 #include "scim_anthy_preedit.h"
 #include "scim_anthy_key2kana_table.h"
@@ -227,6 +226,7 @@ private:
 
     /* utility */
     void   set_preedition                     (void);
+    void   set_aux_string                     (void);
     void   set_lookup_table                   (void);
     void   unset_lookup_table                 (void);
     void   install_properties                 (void);
