@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __SCIM_ANTHY_KEY2KANA_H__
@@ -71,6 +71,7 @@ private:
     Key2KanaTableSet  &m_tables;
 
     // state
+    KeyEvent           m_last_key;
     WideString         m_pending;
     Key2KanaRule       m_exact_match;
     int                m_pseudo_ascii_mode;
