@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define Uses_SCIM_IMENGINE
@@ -43,7 +43,8 @@ NicolaConvertor::~NicolaConvertor ()
 }
 
 bool
-NicolaConvertor::can_append (const KeyEvent & key)
+NicolaConvertor::can_append (const KeyEvent & key,
+                             bool             ignore_space)
 {
     if (key == m_through_key_event) {
         m_through_key_event = KeyEvent ();
@@ -84,7 +85,7 @@ NicolaConvertor::can_append (const KeyEvent & key)
     }
 
     if (isprint (key.get_ascii_code ()) &&
-        !isspace (key.get_ascii_code ()))
+        (ignore_space || !isspace (key.get_ascii_code ())))
     {
         return true;
     }
@@ -583,6 +584,17 @@ NicolaConvertor::append (const KeyEvent & key,
     return handle_voiced_consonant (result, pending);
 }
 
+bool
+NicolaConvertor::append (const String & str,
+                         WideString   & result,
+                         WideString   & pending)
+{
+    result = utf8_mbstowcs (str);
+    m_pending = WideString ();
+
+    return false;
+}
+
 void
 NicolaConvertor::clear (void)
 {
