@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __SCIM_ANTHY_PREEDIT_H__
@@ -24,7 +24,6 @@
 #define Uses_SCIM_EVENT
 #define Uses_SCIM_ATTRIBUTE
 #define Uses_SCIM_LOOKUP_TABLE
-#include <anthy/anthy.h>
 #include <scim.h>
 #include "scim_anthy_reading.h"
 #include "scim_anthy_conversion.h"
