@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -65,15 +65,15 @@ static GtkWidget *create_kana_window                 (GtkWindow            *pare
 static GtkWidget *create_nicola_window               (GtkWindow            *parent);
 
 static void     setup_kana_page                      (void);
-static void     setup_kana_layout_menu               (GtkOptionMenu        *omenu);
-static void     setup_nicola_layout_menu             (GtkOptionMenu        *omenu);
+static void     setup_kana_layout_menu               (GtkWidget        *omenu);
+static void     setup_nicola_layout_menu             (GtkWidget        *omenu);
 static void     setup_kana_window_value              (ScimAnthyTableEditor *editor);
 static void     setup_nicola_window_value            (ScimAnthyTableEditor *editor);
 
 static bool     load_kana_layout                     (void);
 static bool     load_nicola_layout                   (void);
 
-static void     on_kana_layout_menu_changed          (GtkOptionMenu        *omenu,
+static void     on_kana_layout_menu_changed          (GtkWidget        *omenu,
                                                       gpointer              user_data);
 static void     on_kana_customize_button_clicked     (GtkWidget            *button,
                                                       gpointer              data);
@@ -85,7 +85,7 @@ static void     on_kana_table_editor_remove_entry    (ScimAnthyTableEditor *edit
                                                       gpointer              data);
 static void     on_kana_table_editor_removed_entry   (ScimAnthyTableEditor *editor,
                                                       gpointer              data);
-static void     on_nicola_layout_menu_changed        (GtkOptionMenu        *omenu,
+static void     on_nicola_layout_menu_changed        (GtkWidget        *omenu,
                                                       gpointer              user_data);
 static void     on_nicola_customize_button_clicked   (GtkWidget            *button,
                                                       gpointer              data);
@@ -101,41 +101,57 @@ static void     on_nicola_table_editor_removed_entry (ScimAnthyTableEditor *edit
 GtkWidget *
 kana_page_create_ui (void)
 {
-    GtkWidget *vbox;
+    GtkWidget *vbox, *hbox, *label;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
     vbox = gtk_vbox_new (FALSE, 0);
+#endif
+    gtk_container_set_border_width (GTK_CONTAINER(vbox), 8);
     gtk_widget_show (vbox);
 
+    GtkWidget *table = gtk_table_new (8, 4, FALSE);
+    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 4);
+    gtk_widget_show (table);
+
     // JIS Kana Layout
-    GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 4);
-    gtk_widget_show (hbox);
-
-    GtkWidget *label = gtk_label_new (_("<b>JIS Kana Layout</b>"));
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
-    gtk_widget_show (label);
-
-    GtkWidget *alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 8, 24, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
-    gtk_widget_show (alignment);
+    create_subgroup_label (_("<b>JIS Kana Layout</b>"),
+                           GTK_TABLE (table), 0);
 
     /* kana table */
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
-    gtk_container_add (GTK_CONTAINER (alignment), hbox);
-    gtk_widget_show(hbox);
+    GtkWidget *alignment = gtk_alignment_new (0.0, 0.5, 1.0, 1.0);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 20, 0);
+    gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 1, 2,
+                      (GtkAttachOptions) GTK_FILL,
+                      (GtkAttachOptions) GTK_FILL,
+                      4, 4);
+    gtk_widget_show (alignment);
 
     label = gtk_label_new_with_mnemonic (_("La_yout:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+    gtk_container_add (GTK_CONTAINER (alignment), label);
     gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    hbox = gtk_hbox_new (FALSE, 0);
+#endif
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+    gtk_table_attach_defaults (GTK_TABLE (table), hbox, 1, 4, 1, 2);
+    gtk_widget_show(hbox);
+
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = gtk_combo_box_text_new ();
+#else
     GtkWidget *omenu = gtk_option_menu_new ();
+#endif
     __widget_kana_layout_menu = omenu;
     g_signal_connect (G_OBJECT (omenu), "changed",
                       G_CALLBACK (on_kana_layout_menu_changed), NULL);
-    gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
+    gtk_box_pack_start (GTK_BOX (hbox), omenu, TRUE, TRUE, 2);
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -147,40 +163,54 @@ kana_page_create_ui (void)
     gtk_widget_show (button);
 
 
-    // Thumb Shift Layout
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 4);
-    gtk_widget_show (hbox);
-
-    label = gtk_label_new (_("<b>Thumb Shift Layout</b>"));
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 4);
+    // padding
+    label = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (label), 2, 2, 0, 0);
+    gtk_table_attach (GTK_TABLE (table), label,
+                      0, 4, 2, 3,
+                      (GtkAttachOptions) GTK_FILL,
+                      (GtkAttachOptions) GTK_FILL,
+                      4, 4);
     gtk_widget_show (label);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 24, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 0);
-    gtk_widget_show (alignment);
 
-    GtkWidget *vbox2 = gtk_vbox_new (FALSE, 0);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox2);
-    gtk_widget_show (vbox2);
+    // Thumb Shift Layout
+    create_subgroup_label (_("<b>Thumb Shift Layout</b>"),
+                           GTK_TABLE (table), 3);
 
     /* nicola table */
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
-    gtk_widget_show(hbox);
+    alignment = gtk_alignment_new (0.0, 0.5, 1.0, 1.0);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 20, 0);
+    gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, 4, 5,
+                      (GtkAttachOptions) GTK_FILL,
+                      (GtkAttachOptions) GTK_FILL,
+                      4, 4);
+    gtk_widget_show (alignment);
 
     label = gtk_label_new_with_mnemonic (_("La_yout:"));
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+    gtk_container_add (GTK_CONTAINER (alignment), label);
     gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    hbox = gtk_hbox_new (FALSE, 0);
+#endif
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+    gtk_table_attach_defaults (GTK_TABLE (table), hbox, 1, 4, 4, 5);
+    gtk_widget_show(hbox);
+
+#if GTK_CHECK_VERSION(2, 4, 0)
+    omenu = gtk_combo_box_text_new ();
+#else
     omenu = gtk_option_menu_new ();
+#endif
     __widget_nicola_layout_menu = omenu;
     g_signal_connect (G_OBJECT (omenu), "changed",
                       G_CALLBACK (on_nicola_layout_menu_changed), NULL);
-    gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
+    gtk_box_pack_start (GTK_BOX (hbox), omenu, TRUE, TRUE, 2);
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -192,31 +222,34 @@ kana_page_create_ui (void)
     gtk_widget_show (button);
 
     /* thumb shift keys */
+#if GTK_CHECK_VERSION(3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
+#endif
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     gtk_widget_show (hbox);
 
-    GtkWidget *table = gtk_table_new (2, 2, FALSE);
-    gtk_box_pack_start (GTK_BOX (vbox2), table, FALSE, FALSE, 4);
-    gtk_widget_show (table);
-
     // left
     GtkWidget *widget = create_entry (SCIM_ANTHY_CONFIG_LEFT_THUMB_SHIFT_KEY,
-                                      GTK_TABLE (table), 0);
-    gtk_entry_set_editable (GTK_ENTRY (widget), FALSE);
+                                      GTK_TABLE (table), 5);
+    set_left_padding (widget, 20);
+    gtk_editable_set_editable (GTK_EDITABLE (widget), FALSE);
     widget = create_key_select_button (SCIM_ANTHY_CONFIG_LEFT_THUMB_SHIFT_KEY,
-                                       GTK_TABLE (table), 0);
+                                       GTK_TABLE (table), 5);
 
     // right
     widget = create_entry (SCIM_ANTHY_CONFIG_RIGHT_THUMB_SHIFT_KEY,
-                           GTK_TABLE (table), 1);
-    gtk_entry_set_editable (GTK_ENTRY (widget), FALSE);
+                           GTK_TABLE (table), 6);
+    set_left_padding (widget, 20);
+    gtk_editable_set_editable (GTK_EDITABLE (widget), FALSE);
     widget = create_key_select_button (SCIM_ANTHY_CONFIG_RIGHT_THUMB_SHIFT_KEY,
-                                       GTK_TABLE (table), 1);
+                                       GTK_TABLE (table), 6);
 
     /* NICOLA time */
-    create_spin_button (SCIM_ANTHY_CONFIG_NICOLA_TIME,
-                        GTK_TABLE (table), 3);
+    widget = create_spin_button (SCIM_ANTHY_CONFIG_NICOLA_TIME,
+                                 GTK_TABLE (table), 7);
+    set_left_padding (widget, 20);
 
     // prepare
     setup_kana_page ();
@@ -267,30 +300,53 @@ create_kana_window (GtkWindow *parent)
     gtk_window_set_transient_for (GTK_WINDOW (dialog),
                                   GTK_WINDOW (parent));
     gtk_window_set_title (GTK_WINDOW (dialog),
-                          _("Customize kana layout table"));
+                          _("Customize Kana Layout Table"));
 
     // option menu area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_box_pack_start
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, FALSE, FALSE, 0);
+    gtk_box_reorder_child 
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, 0);
+#else
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
                         FALSE, FALSE, 0);
     gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, 0);
+#endif
     gtk_widget_show(hbox);
 
     GtkWidget *label = gtk_label_new_with_mnemonic (_("Layout _table:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
     gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = gtk_combo_box_text_new ();
+#else
     GtkWidget *omenu = gtk_option_menu_new ();
+#endif
     __widget_kana_layout_menu2 = omenu;
     g_object_add_weak_pointer (G_OBJECT (omenu),
                                (gpointer*) &__widget_kana_layout_menu2);
     gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
-    setup_kana_layout_menu (GTK_OPTION_MENU (omenu));
+    setup_kana_layout_menu (omenu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+		GTK_COMBO_BOX (omenu),
+		gtk_combo_box_get_active (GTK_COMBO_BOX (__widget_kana_layout_menu)));
+#else
     gtk_option_menu_set_history
         (GTK_OPTION_MENU (omenu),
          gtk_option_menu_get_history (
              GTK_OPTION_MENU (__widget_kana_layout_menu)));
+#endif
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -339,30 +395,53 @@ create_nicola_window (GtkWindow *parent)
     gtk_window_set_transient_for (GTK_WINDOW (dialog),
                                   GTK_WINDOW (parent));
     gtk_window_set_title (GTK_WINDOW (dialog),
-                          _("Customize thumb shift layout table"));
+                          _("Customize Thumb Shift Layout Table"));
 
     // option menu area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_box_pack_start
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, FALSE, FALSE, 0);
+    gtk_box_reorder_child 
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, 0);
+#else
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
                         FALSE, FALSE, 0);
     gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, 0);
+#endif
     gtk_widget_show(hbox);
 
     GtkWidget *label = gtk_label_new_with_mnemonic (_("Layout _table:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
     gtk_widget_show (label);
-
+    
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = gtk_combo_box_text_new ();
+#else
     GtkWidget *omenu = gtk_option_menu_new ();
+#endif
     __widget_nicola_layout_menu2 = omenu;
     g_object_add_weak_pointer (G_OBJECT (omenu),
                                (gpointer*) &__widget_nicola_layout_menu2);
     gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
-    setup_nicola_layout_menu (GTK_OPTION_MENU (omenu));
+    setup_nicola_layout_menu (omenu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+		GTK_COMBO_BOX (omenu),
+		gtk_combo_box_get_active (GTK_COMBO_BOX (__widget_nicola_layout_menu)));
+#else
     gtk_option_menu_set_history
         (GTK_OPTION_MENU (omenu),
          gtk_option_menu_get_history (
              GTK_OPTION_MENU (__widget_nicola_layout_menu)));
+#endif
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -397,13 +476,48 @@ create_nicola_window (GtkWindow *parent)
 static void
 setup_kana_page (void)
 {
-    setup_kana_layout_menu (GTK_OPTION_MENU (__widget_kana_layout_menu));
-    setup_nicola_layout_menu (GTK_OPTION_MENU (__widget_nicola_layout_menu));
+    setup_kana_layout_menu (__widget_kana_layout_menu);
+    setup_nicola_layout_menu (__widget_nicola_layout_menu);
 }
 
 static void
-setup_kana_layout_menu (GtkOptionMenu *omenu)
+setup_kana_layout_menu (GtkWidget *omenu)
 {
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("User defined"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("Default"));
+
+    gint active_index = KANA_LAYOUT_INDEX_DEFAULT;
+    bool check_list = false;
+    if (__config_kana_layout_file == __user_style_file.get_file_name ()) {
+        active_index = KANA_LAYOUT_INDEX_USER_DEFINED;
+    } else {
+        check_list = true;
+    }
+
+    StyleFiles::iterator it;
+    gint i;
+    for (i = 0, it = __style_list.begin ();
+         it != __style_list.end ();
+         i++, it++)
+    {
+        StyleLines section;
+        if (!it->get_entry_list (section, __kana_fund_table))
+            continue;
+
+		gtk_combo_box_text_append_text 
+			(GTK_COMBO_BOX_TEXT (omenu), _(it->get_title().c_str()));
+
+        if (check_list) {
+            if (it->get_file_name () == __config_kana_layout_file) {
+                active_index = i + 2; // 2: user-define + default
+                check_list = false;
+            }
+        }
+    }
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (omenu), active_index);
+#else
     GtkWidget *menu = gtk_menu_new ();
     gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu),
                               menu);
@@ -466,11 +580,47 @@ setup_kana_layout_menu (GtkOptionMenu *omenu)
         G_OBJECT (omenu),
         (gpointer) (on_kana_layout_menu_changed),
         NULL);
+#endif
 }
 
 static void
-setup_nicola_layout_menu (GtkOptionMenu *omenu)
+setup_nicola_layout_menu (GtkWidget *omenu)
 {
+#if GTK_CHECK_VERSION(2, 4, 0)
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("User defined"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("Default"));
+
+    gint active_index = NICOLA_LAYOUT_INDEX_DEFAULT;
+    bool check_list = false;
+    if (__config_nicola_layout_file == __user_style_file.get_file_name ()) {
+        active_index = NICOLA_LAYOUT_INDEX_USER_DEFINED;
+    } else {
+        check_list = true;
+    }
+
+    StyleFiles::iterator it;
+    gint i;
+    for (i = 0, it = __style_list.begin ();
+         it != __style_list.end ();
+         i++, it++)
+    {
+        StyleLines section;
+        if (!it->get_entry_list (section, __nicola_fund_table))
+            continue;
+
+		gtk_combo_box_text_append_text (
+			GTK_COMBO_BOX_TEXT (omenu), _(it->get_title().c_str()));
+
+        if (check_list) {
+            if (it->get_file_name () == __config_nicola_layout_file) {
+                active_index = i + 2; // 2: user-define + default
+                check_list = false;
+            }
+        }
+    }
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (omenu), active_index);
+#else
     GtkWidget *menu = gtk_menu_new ();
     gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu),
                               menu);
@@ -533,6 +683,7 @@ setup_nicola_layout_menu (GtkOptionMenu *omenu)
         G_OBJECT (omenu),
         (gpointer) (on_nicola_layout_menu_changed),
         NULL);
+#endif
 }
 
 static void
@@ -647,7 +798,11 @@ setup_default_nicola_table (void)
 static bool
 load_kana_layout (void)
 {
-    GtkOptionMenu *omenu = GTK_OPTION_MENU (__widget_kana_layout_menu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gint idx = gtk_combo_box_get_active (GTK_COMBO_BOX (__widget_kana_layout_menu));
+    gint theme_idx = idx - 2; // user definad and default
+#else
+    GtkWidget *omenu = GTK_OPTION_MENU (__widget_kana_layout_menu);
     gint idx = gtk_option_menu_get_history (omenu);
     GtkWidget *menu = gtk_option_menu_get_menu (omenu);
     GList *list = gtk_container_get_children (GTK_CONTAINER (menu));
@@ -658,7 +813,8 @@ load_kana_layout (void)
 
     gint theme_idx = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem),
                                                          INDEX_KEY));
-
+#endif
+    
     // set new kana table
     if (idx == KANA_LAYOUT_INDEX_USER_DEFINED) {
         // User defined table
@@ -707,7 +863,11 @@ load_kana_layout (void)
 static bool
 load_nicola_layout (void)
 {
-    GtkOptionMenu *omenu = GTK_OPTION_MENU (__widget_nicola_layout_menu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gint idx = gtk_combo_box_get_active (GTK_COMBO_BOX (__widget_nicola_layout_menu));
+    gint theme_idx = idx - 2; // user definad and default
+#else
+    GtkWidget *omenu = GTK_OPTION_MENU (__widget_nicola_layout_menu);
     gint idx = gtk_option_menu_get_history (omenu);
     GtkWidget *menu = gtk_option_menu_get_menu (omenu);
     GList *list = gtk_container_get_children (GTK_CONTAINER (menu));
@@ -718,7 +878,8 @@ load_nicola_layout (void)
 
     gint theme_idx = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem),
                                                          INDEX_KEY));
-
+#endif
+    
     // set new NICOLA table
     if (idx == NICOLA_LAYOUT_INDEX_USER_DEFINED) {
         // User defined table
@@ -785,7 +946,7 @@ has_voiced_consonant (String str)
 }
 
 static void
-on_kana_layout_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
+on_kana_layout_menu_changed (GtkWidget *omenu, gpointer user_data)
 {
     bool success;
 
@@ -794,9 +955,15 @@ on_kana_layout_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
             G_OBJECT (__widget_kana_layout_menu),
             (gpointer) (on_kana_layout_menu_changed),
             NULL);
+#if GTK_CHECK_VERSION(2, 4, 0)
+        gtk_combo_box_set_active (
+            GTK_COMBO_BOX (__widget_kana_layout_menu),
+            gtk_combo_box_get_active (GTK_COMBO_BOX (omenu)));
+#else
         gtk_option_menu_set_history (
             GTK_OPTION_MENU (__widget_kana_layout_menu),
-            gtk_option_menu_get_history (omenu));
+            gtk_option_menu_get_history (GTK_OPTION_MENU(omenu)));
+#endif
         g_signal_handlers_unblock_by_func (
             G_OBJECT (__widget_kana_layout_menu),
             (gpointer) (on_kana_layout_menu_changed),
@@ -844,10 +1011,16 @@ static void
 on_kana_table_editor_added_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User defined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_kana_layout_menu2),
+        KANA_LAYOUT_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_kana_layout_menu2),
         KANA_LAYOUT_INDEX_USER_DEFINED);
-
+#endif
+    
     __style_changed = true;
 }
 
@@ -865,15 +1038,21 @@ static void
 on_kana_table_editor_removed_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User deined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_kana_layout_menu2),
+        KANA_LAYOUT_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_kana_layout_menu2),
         KANA_LAYOUT_INDEX_USER_DEFINED);
-
+#endif
+    
     __style_changed = true;
 }
 
 static void
-on_nicola_layout_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
+on_nicola_layout_menu_changed (GtkWidget *omenu, gpointer user_data)
 {
     bool success;
 
@@ -882,9 +1061,15 @@ on_nicola_layout_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
             G_OBJECT (__widget_nicola_layout_menu),
             (gpointer) (on_nicola_layout_menu_changed),
             NULL);
+#if GTK_CHECK_VERSION(2, 4, 0)
+        gtk_combo_box_set_active (
+            GTK_COMBO_BOX (__widget_nicola_layout_menu),
+            gtk_combo_box_get_active (GTK_COMBO_BOX (omenu)));
+#else
         gtk_option_menu_set_history (
             GTK_OPTION_MENU (__widget_nicola_layout_menu),
-            gtk_option_menu_get_history (omenu));
+            gtk_option_menu_get_history (GTK_OPTION_MENU(omenu)));
+#endif
         g_signal_handlers_unblock_by_func (
             G_OBJECT (__widget_nicola_layout_menu),
             (gpointer) (on_nicola_layout_menu_changed),
@@ -928,9 +1113,15 @@ static void
 on_nicola_table_editor_added_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User defined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_nicola_layout_menu2),
+        NICOLA_LAYOUT_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_nicola_layout_menu2),
         NICOLA_LAYOUT_INDEX_USER_DEFINED);
+#endif
 
     __style_changed = true;
 }
@@ -949,10 +1140,16 @@ static void
 on_nicola_table_editor_removed_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User deined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_nicola_layout_menu2),
+        NICOLA_LAYOUT_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_nicola_layout_menu2),
         NICOLA_LAYOUT_INDEX_USER_DEFINED);
-
+#endif
+    
     __style_changed = true;
 }
 
