@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,14 +55,14 @@ static String __config_romaji_theme_file = SCIM_ANTHY_CONFIG_ROMAJI_THEME_FILE_D
 static GtkWidget *create_romaji_window            (GtkWindow            *parent);
 
 static void     setup_romaji_page                 (void);
-static void     setup_romaji_theme_menu           (GtkOptionMenu        *omenu);
+static void     setup_romaji_theme_menu           (GtkWidget        *omenu);
 static void     setup_romaji_window_value         (ScimAnthyTableEditor *editor);
 
 static bool     load_romaji_theme                 (void);
 
 static void     on_romaji_pseudo_ascii_mode_toggled(GtkToggleButton *togglebutton,
                                                     gpointer         user_data);
-static void     on_romaji_theme_menu_changed       (GtkOptionMenu        *omenu,
+static void     on_romaji_theme_menu_changed       (GtkWidget        *omenu,
                                                     gpointer              user_data);
 static void     on_romaji_customize_button_clicked (GtkWidget            *button,
                                                     gpointer              data);
@@ -78,58 +78,73 @@ static void     on_table_editor_removed_entry      (ScimAnthyTableEditor *editor
 GtkWidget *
 romaji_page_create_ui (void)
 {
-    GtkWidget *vbox, *widget, *hbox, *label;
+    GtkWidget *vbox, *hbox, *table, *widget, *label;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
     vbox = gtk_vbox_new (FALSE, 0);
+#endif
+    gtk_container_set_border_width (GTK_CONTAINER(vbox), 8);
     gtk_widget_show (vbox);
 
+    table = gtk_table_new (8, 2, FALSE);
+    gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
+    gtk_widget_show (table);
+
     /* romaji splitting */
-    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_ALLOW_SPLIT);
-    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
+    create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_ALLOW_SPLIT,
+                         GTK_TABLE (table), 0);
 
     /* symbol */
-    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_HALF_SYMBOL);
-    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
+    create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_HALF_SYMBOL,
+                         GTK_TABLE (table), 1);
 
     /* number */
-    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_HALF_NUMBER);
-    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
+    create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_HALF_NUMBER,
+                         GTK_TABLE (table), 2);
 
     /* pseudo ascii mode */
-    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_MODE);
+    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_MODE,
+                                  GTK_TABLE (table), 3);
     g_signal_connect ((gpointer) widget, "toggled",
                       G_CALLBACK (on_romaji_pseudo_ascii_mode_toggled),
                       NULL);
-    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 4);
 
     /* pseudo ascii: blank behavior */
-    hbox = gtk_hbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 4);
-    gtk_widget_show (hbox);
-    label = gtk_label_new ("    ");
-    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-    gtk_widget_show (label);
-
-    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_BLANK_BEHAVIOR);
-    gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+    widget = create_check_button (SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_BLANK_BEHAVIOR,
+                                  GTK_TABLE (table), 4);
+    set_left_padding (widget, 20);
     // set initial state
     on_romaji_pseudo_ascii_mode_toggled (GTK_TOGGLE_BUTTON (widget), NULL);
 
     /* romaji table */
+#if GTK_CHECK_VERSION(3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     hbox = gtk_hbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
-    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    gtk_table_attach (GTK_TABLE (table), hbox,
+                      0, 4, 5, 6,
+                      (GtkAttachOptions) GTK_FILL,
+                      (GtkAttachOptions) GTK_FILL,
+                      4, 4);
     gtk_widget_show(hbox);
 
     label = gtk_label_new_with_mnemonic (_("Romaji _table:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
     gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = gtk_combo_box_text_new ();
+#else
     GtkWidget *omenu = gtk_option_menu_new ();
+#endif
     __widget_romaji_theme_menu = omenu;
     g_signal_connect (G_OBJECT (omenu), "changed",
                       G_CALLBACK (on_romaji_theme_menu_changed), NULL);
-    gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
+    gtk_box_pack_start (GTK_BOX (hbox), omenu, TRUE, TRUE, 2);
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -182,30 +197,52 @@ create_romaji_window (GtkWindow *parent)
     gtk_window_set_transient_for (GTK_WINDOW (dialog),
                                   GTK_WINDOW (parent));
     gtk_window_set_title (GTK_WINDOW (dialog),
-                          _("Customize romaji table"));
+                          _("Customize Romaji Table"));
 
     // option menu area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_box_pack_start
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, FALSE, FALSE, 0);
+    gtk_box_reorder_child 
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+		 hbox, 0);
+#else
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
                         FALSE, FALSE, 0);
     gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, 0);
+#endif
     gtk_widget_show(hbox);
 
     GtkWidget *label = gtk_label_new_with_mnemonic (_("Romaji _table:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 2);
     gtk_widget_show (label);
 
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = gtk_combo_box_text_new ();
+#else
     GtkWidget *omenu = gtk_option_menu_new ();
+#endif
     __widget_romaji_theme_menu2 = omenu;
     g_object_add_weak_pointer (G_OBJECT (omenu),
                                (gpointer*) &__widget_romaji_theme_menu2);
     gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 2);
-    setup_romaji_theme_menu (GTK_OPTION_MENU (omenu));
+    setup_romaji_theme_menu (omenu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (GTK_COMBO_BOX (omenu),
+         gtk_combo_box_get_active (GTK_COMBO_BOX (__widget_romaji_theme_menu)));
+#else
     gtk_option_menu_set_history
         (GTK_OPTION_MENU (omenu),
          gtk_option_menu_get_history (
              GTK_OPTION_MENU (__widget_romaji_theme_menu)));
+#endif
     gtk_widget_show (omenu);
 
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), omenu);
@@ -240,12 +277,47 @@ create_romaji_window (GtkWindow *parent)
 static void
 setup_romaji_page (void)
 {
-    setup_romaji_theme_menu (GTK_OPTION_MENU (__widget_romaji_theme_menu));
+    setup_romaji_theme_menu (__widget_romaji_theme_menu);
 }
 
 static void
-setup_romaji_theme_menu (GtkOptionMenu *omenu)
+setup_romaji_theme_menu (GtkWidget *omenu)
 {
+#if GTK_CHECK_VERSION(2, 4, 0)
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("User defined"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (omenu), _("Default"));
+
+	gint active_index = ROMAJI_THEME_INDEX_DEFAULT;
+    bool check_list = false;
+    if (__config_romaji_theme_file == __user_style_file.get_file_name ()) {
+		active_index = ROMAJI_THEME_INDEX_USER_DEFINED;
+	} else {
+        check_list = true;
+	}
+
+    StyleFiles::iterator it;
+    unsigned int i;
+    for (i = 0, it = __style_list.begin ();
+         it != __style_list.end ();
+         i++, it++)
+    {
+        StyleLines section;
+        if (!it->get_entry_list (section, __romaji_fund_table))
+            continue;
+
+		gtk_combo_box_text_append_text 
+			(GTK_COMBO_BOX_TEXT (omenu), _(it->get_title().c_str()));
+
+        if (check_list) {
+            if (it->get_file_name () == __config_romaji_theme_file) {
+                active_index = i + 2; // 2: user-define + default
+                check_list = false;
+			}
+		}
+    }
+
+    gtk_combo_box_set_active (GTK_COMBO_BOX (omenu), active_index);
+#else
     GtkWidget *menu = gtk_menu_new ();
     gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu),
                               menu);
@@ -308,6 +380,7 @@ setup_romaji_theme_menu (GtkOptionMenu *omenu)
         G_OBJECT (omenu),
         (gpointer) (on_romaji_theme_menu_changed),
         NULL);
+#endif
 }
 
 static void
@@ -367,7 +440,12 @@ setup_default_romaji_table (void)
 static bool
 load_romaji_theme (void)
 {
-    GtkOptionMenu *omenu = GTK_OPTION_MENU (__widget_romaji_theme_menu);
+#if GTK_CHECK_VERSION(2, 4, 0)
+    GtkWidget *omenu = __widget_romaji_theme_menu;
+    gint idx = gtk_combo_box_get_active (GTK_COMBO_BOX (omenu));
+	gint theme_idx = idx - 2; // 2: user-defined + default
+#else
+    GtkWidget *omenu = GTK_OPTION_MENU (__widget_romaji_theme_menu);
     gint idx = gtk_option_menu_get_history (omenu);
     GtkWidget *menu = gtk_option_menu_get_menu (omenu);
     GList *list = gtk_container_get_children (GTK_CONTAINER (menu));
@@ -378,7 +456,8 @@ load_romaji_theme (void)
 
     gint theme_idx = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (menuitem),
                                                          INDEX_KEY));
-
+#endif
+    
     // set new romaji table
     if (idx == ROMAJI_THEME_INDEX_USER_DEFINED) {
         // User defined table
@@ -437,7 +516,7 @@ on_romaji_pseudo_ascii_mode_toggled (GtkToggleButton *togglebutton,
 }
 
 static void
-on_romaji_theme_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
+on_romaji_theme_menu_changed (GtkWidget *omenu, gpointer user_data)
 {
     bool success;
 
@@ -446,9 +525,15 @@ on_romaji_theme_menu_changed (GtkOptionMenu *omenu, gpointer user_data)
             G_OBJECT (__widget_romaji_theme_menu),
             (gpointer) (on_romaji_theme_menu_changed),
             NULL);
+#if GTK_CHECK_VERSION(2, 4, 0)
+        gtk_combo_box_set_active (
+            GTK_COMBO_BOX (__widget_romaji_theme_menu),
+            gtk_combo_box_get_active (GTK_COMBO_BOX (omenu)));
+#else
         gtk_option_menu_set_history (
             GTK_OPTION_MENU (__widget_romaji_theme_menu),
-            gtk_option_menu_get_history (omenu));
+            gtk_option_menu_get_history (GTK_OPTION_MENU(omenu)));
+#endif
         g_signal_handlers_unblock_by_func (
             G_OBJECT (__widget_romaji_theme_menu),
             (gpointer) (on_romaji_theme_menu_changed),
@@ -492,10 +577,16 @@ static void
 on_table_editor_added_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User defined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_romaji_theme_menu2),
+        ROMAJI_THEME_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_romaji_theme_menu2),
         ROMAJI_THEME_INDEX_USER_DEFINED);
-
+#endif
+    
     __style_changed = true;
 }
 
@@ -515,10 +606,16 @@ static void
 on_table_editor_removed_entry (ScimAnthyTableEditor *editor, gpointer data)
 {
     // change menu item to "User deined"
+#if GTK_CHECK_VERSION(2, 4, 0)
+    gtk_combo_box_set_active (
+        GTK_COMBO_BOX (__widget_romaji_theme_menu2),
+        ROMAJI_THEME_INDEX_USER_DEFINED);
+#else
     gtk_option_menu_set_history (
         GTK_OPTION_MENU (__widget_romaji_theme_menu2),
         ROMAJI_THEME_INDEX_USER_DEFINED);
-
+#endif
+    
     __style_changed = true;
 }
 
