@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -131,11 +131,41 @@ scim_anthy_table_editor_init (ScimAnthyTableEditor *editor)
     gtk_window_set_position (GTK_WINDOW (editor),
                              GTK_WIN_POS_CENTER_ON_PARENT);
 
-    // edit area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkWidget *hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_box_pack_start
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (editor))),
+		 hbox, TRUE, TRUE, 0);
+#else
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), hbox,
                         TRUE, TRUE, 0);
+#endif
+    gtk_widget_show (hbox);
+
+    GtkWidget *label = gtk_label_new_with_mnemonic (_("Table _entries:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_widget_show (label);
+
+    // edit area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    hbox = gtk_hbox_new (FALSE, 0);
+#endif
+    gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+#if GTK_CHECK_VERSION(3, 0, 0)
+    gtk_box_pack_start
+		(GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (editor))),
+		 hbox, TRUE, TRUE, 0);
+#else
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editor)->vbox), hbox,
+                        TRUE, TRUE, 0);
+#endif
     gtk_widget_show (hbox);
 
     // tree view area
@@ -153,6 +183,8 @@ scim_anthy_table_editor_init (ScimAnthyTableEditor *editor)
     gtk_container_add (GTK_CONTAINER (scrwin), treeview);
     gtk_widget_show (treeview);
 
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), treeview);
+
     GtkTreeSelection *selection;
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
     g_signal_connect (G_OBJECT (selection), "changed",
@@ -162,7 +194,11 @@ scim_anthy_table_editor_init (ScimAnthyTableEditor *editor)
     gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (treeview), TRUE);
 
     // button area
+#if GTK_CHECK_VERSION(3, 0, 0)
+    GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
     GtkWidget *vbox = gtk_vbox_new (FALSE, 0);
+#endif
     editor->button_area = vbox;
     gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 5);
     gtk_widget_show (vbox);
